Index: wp-includes/link-template.php
===================================================================
--- wp-includes/link-template.php	(revision 23975)
+++ wp-includes/link-template.php	(working copy)
@@ -2036,16 +2036,26 @@
  * @package WordPress
  * @since 2.6.0
  *
  * @param string $path Optional. Path relative to the content url.
  * @return string Content url link with optional path appended.
 */
 function content_url($path = '') {
 	$url = set_url_scheme( WP_CONTENT_URL );
+	$original_path = $path;
 
-	if ( $path && is_string( $path ) )
+	if ( $path && is_string( $path ) ) {
+		// Handle absolute path pointing inside WP_CONTENT_DIR
+		if ( strpos( $path, WP_CONTENT_DIR ) === 0 ) {
+			$path = realpath($path);
+			$content_dir_segment = DIRECTORY_SEPARATOR . basename( WP_CONTENT_DIR ) . DIRECTORY_SEPARATOR;
+			$until_content_dir_pattern = sprintf( '#^.+%s#', preg_quote( $content_dir_segment, '#' ) );
+			$path = preg_replace( $until_content_dir_pattern, '', $path );
+			$path = str_replace('\\', '/', $path); // sanitize for Win32 installs
+		}
 		$url .= '/' . ltrim($path, '/');
+	}
 
-	return apply_filters('content_url', $url, $path);
+	return apply_filters('content_url', $url, $original_path);
 }
 
 /**
@@ -2036,16 +2036,26 @@
  * @since 2.6.0
  *
- * @param string $path Optional. Path relative to the content url.
+ * @param string $path Optional. Path relative to the content url, or an absolute real path pointing inside WP_CONTENT_DIR
  * @return string Content url link with optional path appended.
 */
